==> libitext5-java_5.4.4.orig.tar.xz: itext/src/main/java/com/itextpdf/text/pdf/internal/PdfIsoKeys.java <==
/*
 * $Id: PdfIsoKeys.java 5914 2013-07-28 14:18:11Z blowagie $
 *
 * This file is part of the iText (R) project.
 * Copyright (c) 1998-2013 1T3XT BVBA
 * Authors: Bruno Lowagie, Paulo Soares, et al.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation with the addition of the
 * following permission added to Section 15 as permitted in Section 7(a):
 * FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY 1T3XT,
 * 1T3XT DISCLAIMS THE WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 * You should have received a copy of the GNU Affero General Public License
 * along with this program; if not, see http://www.gnu.org/licenses or write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA, 02110-1301 USA, or download the license from the following URL:
 * http://itextpdf.com/terms-of-use/
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License.
 *
 * In accordance with Section 7(b) of the GNU Affero General Public License,
 * a covered work must retain the producer line in every PDF that is created
 * or manipulated using iText.
 *
 * You can be released from the requirements of the license by purchasing
 * a commercial license. Buying such a license is mandatory as soon as you
 * develop commercial activities involving the iText software without
 * disclosing the source code of your own applications.
 * These activities include: offering paid services to customers as an ASP,
 * serving PDFs on the fly in a web application, shipping iText with a closed
 * source product.
 *
 * For more information, please contact iText Software Corp. at this
 * address: sales@itextpdf.com
 */
package com.itextpdf.text.pdf.internal;

public class PdfIsoKeys {
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_COLOR = 1;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_CMYK = 2;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_RGB = 3;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_FONT = 4;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_IMAGE = 5;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_GSTATE = 6;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_LAYER = 7;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_TRAILER = 8;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_STREAM = 9;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_FILESPEC = 10;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_OBJECT = 11;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_CANVAS = 12;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_ANNOTATION = 13;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_ACTION = 14;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_FORM = 15;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_STRUCTELEM = 16;
}

==> libitext5-java_5.4.5.orig.tar.xz: itext/src/main/java/com/itextpdf/text/pdf/internal/PdfIsoKeys.java <==
/*
 * $Id: PdfIsoKeys.java 6044 2013-10-29 08:22:47Z eugenemark $
 *
 * This file is part of the iText (R) project.
 * Copyright (c) 1998-2013 1T3XT BVBA
 * Authors: Bruno Lowagie, Paulo Soares, et al.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation with the addition of the
 * following permission added to Section 15 as permitted in Section 7(a):
 * FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY 1T3XT,
 * 1T3XT DISCLAIMS THE WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 * You should have received a copy of the GNU Affero General Public License
 * along with this program; if not, see http://www.gnu.org/licenses or write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA, 02110-1301 USA, or download the license from the following URL:
 * http://itextpdf.com/terms-of-use/
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License.
 *
 * In accordance with Section 7(b) of the GNU Affero General Public License,
 * a covered work must retain the producer line in every PDF that is created
 * or manipulated using iText.
 *
 * You can be released from the requirements of the license by purchasing
 * a commercial license. Buying such a license is mandatory as soon as you
 * develop commercial activities involving the iText software without
 * disclosing the source code of your own applications.
 * These activities include: offering paid services to customers as an ASP,
 * serving PDFs on the fly in a web application, shipping iText with a closed
 * source product.
 *
 * For more information, please contact iText Software Corp. at this
 * address: sales@itextpdf.com
 */
package com.itextpdf.text.pdf.internal;

public class PdfIsoKeys {
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_COLOR = 1;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_CMYK = 2;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_RGB = 3;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_FONT = 4;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_IMAGE = 5;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_GSTATE = 6;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_LAYER = 7;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_TRAILER = 8;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_STREAM = 9;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_FILESPEC = 10;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_OBJECT = 11;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_CANVAS = 12;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_ANNOTATION = 13;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_ACTION = 14;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_FORM = 15;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_STRUCTELEM = 16;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_INLINE_IMAGE = 17;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_GRAY = 18;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_OUTPUTINTENT = 19;
    /** A key for an aspect that can be checked for PDF ISO Conformance. */
    public static final int PDFISOKEY_FORM_XOBJ = 20;
}
